==> AsposeCellsCloud-CellsApi-25.10.tar.gz: AsposeCellsCloud-CellsApi-25.10/docs/model/Form.md <==
# AsposeCellsCloud::Object::Form 

## Load the model package
```perl
use AsposeCellsCloud::Object::Form;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**FormType** | **string** | A property named "FormType" of type string which can be both accessed and modified. |
**CheckedValue** | **string** |  |
**Shadow** | **boolean** |  |
**InputRange** | **string** |  |
**SelectedIndex** | **int** |  |
**SelectedValue** | **string** |  |
**SelectedCell** | **LinkElement** |  |
**DropDownLines** | **int** |  |
**ItemCount** | **int** |  |
**SelectedCells** | **ARRAY[LinkElement]** |  |
**SelectionType** | **string** |  |
**IsChecked** | **boolean** |  |
**CurrentValue** | **int** |  |
**Min** | **int** |  |
**Max** | **int** |  |
**IncrementalChange** | **int** |  |
**PageChange** | **int** |  |
**IsHorizontal** | **boolean** |  |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/Form.md <==
# AsposeCellsCloud::Object::Form 

## Load the model package
```perl
use AsposeCellsCloud::Object::Form;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**FormType** | **string** | A property named "FormType" of type string which can be both accessed and modified. |
**CheckedValue** | **string** |  |
**Shadow** | **boolean** |  |
**InputRange** | **string** |  |
**SelectedIndex** | **int** |  |
**SelectedValue** | **string** |  |
**SelectedCell** | **LinkElement** |  |
**DropDownLines** | **int** |  |
**ItemCount** | **int** |  |
**SelectedCells** | **ARRAY[LinkElement]** |  |
**SelectionType** | **string** |  |
**IsChecked** | **boolean** |  |
**CurrentValue** | **int** |  |
**Min** | **int** |  |
**Max** | **int** |  |
**IncrementalChange** | **int** |  |
**PageChange** | **int** |  |
**IsHorizontal** | **boolean** |  |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
